# magcluster
Magnetosome gene cluster annotation, screening and mapping tool
## Installation
Run the following to install:
pip install magcluster
## General Usage
Magnetosome gene annotation:  
  $ magcluster maga XXX.fa  

Magnetosome gene screen:  
  $ magcluster magsc XXX.faa XXX.gbk  
  
Magnetosome gene cluster mapping:  
  $ magcluster magm XXX_screened.gbk  